==> jc-1.4.0.tar.gz: javax/swing/text/html/HTML__24UnknownTag.h <==
// public class javax.swing.text.html.HTML$UnknownTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e195b3a296492665 javax_swing_text_html_HTML__24Tag
// @dep_class 51da1f48373035e8 javax_swing_text_html_HTML__24UnknownTag

// header file dependencies
// @dep_header javax_swing_text_html_HTML__24Tag

#include "javax/swing/text/html/HTML__24Tag.h"

#ifndef _JC_javax_swing_text_html_HTML__24UnknownTag_H_
#define _JC_javax_swing_text_html_HTML__24UnknownTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_html_HTML__24UnknownTag$sub_refs	_jc_javax_swing_text_html_HTML__24UnknownTag$sub_refs;
typedef struct _jc_javax_swing_text_html_HTML__24UnknownTag$sub_nonrefs	_jc_javax_swing_text_html_HTML__24UnknownTag$sub_nonrefs;
typedef struct _jc_javax_swing_text_html_HTML__24UnknownTag$refs	_jc_javax_swing_text_html_HTML__24UnknownTag$refs;
typedef struct _jc_javax_swing_text_html_HTML__24UnknownTag$nonrefs	_jc_javax_swing_text_html_HTML__24UnknownTag$nonrefs;
typedef struct _jc_javax_swing_text_html_HTML__24UnknownTag$object	_jc_javax_swing_text_html_HTML__24UnknownTag$object;

typedef struct _jc_javax_swing_text_html_HTML__24UnknownTag$fields_struct	_jc_javax_swing_text_html_HTML__24UnknownTag$fields_struct;
typedef const struct _jc_javax_swing_text_html_HTML__24UnknownTag$vmethods	_jc_javax_swing_text_html_HTML__24UnknownTag$vmethods;
typedef const struct _jc_javax_swing_text_html_HTML__24UnknownTag$vtable	_jc_javax_swing_text_html_HTML__24UnknownTag$vtable;
typedef const struct _jc_javax_swing_text_html_HTML__24UnknownTag$vtype	_jc_javax_swing_text_html_HTML__24UnknownTag$vtype;

// Class fields structure
struct _jc_javax_swing_text_html_HTML__24UnknownTag$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_html_HTML__24UnknownTag$fields_struct _jc_javax_swing_text_html_HTML__24UnknownTag$class_fields;

// Constructors
extern void _jc_javax_swing_text_html_HTML__24UnknownTag$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_html_HTML__24UnknownTag$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_swing_text_html_HTML__24UnknownTag$vmethods {
};

// Vtable
struct _jc_javax_swing_text_html_HTML__24UnknownTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_html_HTML__24Tag$vmethods	javax_swing_text_html_HTML__24Tag;
	_jc_javax_swing_text_html_HTML__24UnknownTag$vmethods	javax_swing_text_html_HTML__24UnknownTag;
};

// Vtype
struct _jc_javax_swing_text_html_HTML__24UnknownTag$vtype {
	_jc_type			type;
	_jc_javax_swing_text_html_HTML__24UnknownTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_html_HTML__24UnknownTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_html_HTML__24UnknownTag$refs {
    _jc_javax_swing_text_html_HTML__24UnknownTag$sub_refs	javax_swing_text_html_HTML__24UnknownTag;
    _jc_javax_swing_text_html_HTML__24Tag$sub_refs	javax_swing_text_html_HTML__24Tag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_html_HTML__24UnknownTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_html_HTML__24UnknownTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_html_HTML__24Tag$sub_nonrefs	javax_swing_text_html_HTML__24Tag;
    _jc_javax_swing_text_html_HTML__24UnknownTag$sub_nonrefs	javax_swing_text_html_HTML__24UnknownTag;
};

// Object instance structure
struct _jc_javax_swing_text_html_HTML__24UnknownTag$object {
	_jc_javax_swing_text_html_HTML__24UnknownTag$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_html_HTML__24UnknownTag$vtype	*vtype;
	_jc_javax_swing_text_html_HTML__24UnknownTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_html_HTML__24UnknownTag$vtype _jc_javax_swing_text_html_HTML__24UnknownTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_html_HTML__24UnknownTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_html_HTML__24UnknownTag$class_object;

#endif	/* _JC_javax_swing_text_html_HTML__24UnknownTag_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/html/HTML__24UnknownTag.h <==
// public class javax.swing.text.html.HTML$UnknownTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f9e1a7f884b6ed1e javax_swing_text_html_HTML__24Tag
// @dep_class 8afc8a722da27026 javax_swing_text_html_HTML__24UnknownTag

// header file dependencies
// @dep_header javax_swing_text_html_HTML__24Tag

#include "javax/swing/text/html/HTML__24Tag.h"

#ifndef _JC_javax_swing_text_html_HTML__24UnknownTag_H_
#define _JC_javax_swing_text_html_HTML__24UnknownTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_html_HTML__24UnknownTag$sub_refs	_jc_javax_swing_text_html_HTML__24UnknownTag$sub_refs;
typedef struct _jc_javax_swing_text_html_HTML__24UnknownTag$sub_nonrefs	_jc_javax_swing_text_html_HTML__24UnknownTag$sub_nonrefs;
typedef struct _jc_javax_swing_text_html_HTML__24UnknownTag$refs	_jc_javax_swing_text_html_HTML__24UnknownTag$refs;
typedef struct _jc_javax_swing_text_html_HTML__24UnknownTag$nonrefs	_jc_javax_swing_text_html_HTML__24UnknownTag$nonrefs;
typedef struct _jc_javax_swing_text_html_HTML__24UnknownTag$object	_jc_javax_swing_text_html_HTML__24UnknownTag$object;

typedef struct _jc_javax_swing_text_html_HTML__24UnknownTag$fields_struct	_jc_javax_swing_text_html_HTML__24UnknownTag$fields_struct;
typedef const struct _jc_javax_swing_text_html_HTML__24UnknownTag$vmethods	_jc_javax_swing_text_html_HTML__24UnknownTag$vmethods;
typedef const struct _jc_javax_swing_text_html_HTML__24UnknownTag$vtable	_jc_javax_swing_text_html_HTML__24UnknownTag$vtable;
typedef const struct _jc_javax_swing_text_html_HTML__24UnknownTag$vtype	_jc_javax_swing_text_html_HTML__24UnknownTag$vtype;

// Class fields structure
struct _jc_javax_swing_text_html_HTML__24UnknownTag$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_html_HTML__24UnknownTag$fields_struct _jc_javax_swing_text_html_HTML__24UnknownTag$class_fields;

// Constructors
extern void _jc_javax_swing_text_html_HTML__24UnknownTag$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_html_HTML__24UnknownTag$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_text_html_HTML__24UnknownTag$vmethods {
};

// Vtable
struct _jc_javax_swing_text_html_HTML__24UnknownTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_html_HTML__24Tag$vmethods	javax_swing_text_html_HTML__24Tag;
	_jc_javax_swing_text_html_HTML__24UnknownTag$vmethods	javax_swing_text_html_HTML__24UnknownTag;
};

// Vtype
struct _jc_javax_swing_text_html_HTML__24UnknownTag$vtype {
	_jc_type			type;
	_jc_javax_swing_text_html_HTML__24UnknownTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_html_HTML__24UnknownTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_html_HTML__24UnknownTag$refs {
    _jc_javax_swing_text_html_HTML__24UnknownTag$sub_refs	javax_swing_text_html_HTML__24UnknownTag;
    _jc_javax_swing_text_html_HTML__24Tag$sub_refs	javax_swing_text_html_HTML__24Tag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_html_HTML__24UnknownTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_html_HTML__24UnknownTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_html_HTML__24Tag$sub_nonrefs	javax_swing_text_html_HTML__24Tag;
    _jc_javax_swing_text_html_HTML__24UnknownTag$sub_nonrefs	javax_swing_text_html_HTML__24UnknownTag;
};

// Object instance structure
struct _jc_javax_swing_text_html_HTML__24UnknownTag$object {
	_jc_javax_swing_text_html_HTML__24UnknownTag$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_html_HTML__24UnknownTag$vtype	*vtype;
	_jc_javax_swing_text_html_HTML__24UnknownTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_html_HTML__24UnknownTag$vtype _jc_javax_swing_text_html_HTML__24UnknownTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_html_HTML__24UnknownTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_html_HTML__24UnknownTag$class_object;

#endif	/* _JC_javax_swing_text_html_HTML__24UnknownTag_H_ */
